Installation — django-authority v0.2 documentation

### Navigation

- index
- next |
- previous |
- django-authority v0.2 documentation »

# Installation

The installation of django-authority is easy. Whether you want to use the latest stable or development version, you have the following options.

## The latest stable version

The latest, stable version is always available via the Python package index_ (PyPI). You can download the latest version on the site but most users would prefer either `pip` or `easy_install`:

    pip install django-authority

    # .. or with easy_install:

    easy_install django-authority

## Development version

The latest development version is located on it’s Bitbucket account. You can checkout the package using the Mercurial scm:

    hg clone http://bitbucket.org/jezdez/django-authority/

Then install it manually:

    cd django-authority
    python setup.py install

Warning

The development version is not fully tested and may contain bugs, so we prefer to use the latest package from pypi.

### Navigation

- index
- next |
- previous |
- django-authority v0.2 documentation »